==> redux-0.5.1.tgz: package/lib/Container.js <==
'use strict';

var _inherits = require('babel-runtime/helpers/inherits')['default'];

var _get = require('babel-runtime/helpers/get')['default'];

var _createClass = require('babel-runtime/helpers/create-class')['default'];

var _classCallCheck = require('babel-runtime/helpers/class-call-check')['default'];

var _extends = require('babel-runtime/helpers/extends')['default'];

var _Object$defineProperty = require('babel-runtime/core-js/object/define-property')['default'];

var _Object$keys = require('babel-runtime/core-js/object/keys')['default'];

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

_Object$defineProperty(exports, '__esModule', {
  value: true
});

var _react = require('react');

var _lodashObjectMapValues = require('lodash/object/mapValues');

var _lodashObjectMapValues2 = _interopRequireDefault(_lodashObjectMapValues);

var _lodashUtilityIdentity = require('lodash/utility/identity');

var _lodashUtilityIdentity2 = _interopRequireDefault(_lodashUtilityIdentity);

var _invariant = require('invariant');

var _invariant2 = _interopRequireDefault(_invariant);

var _lodashLangIsPlainObject = require('lodash/lang/isPlainObject');

var _lodashLangIsPlainObject2 = _interopRequireDefault(_lodashLangIsPlainObject);

var ReduxContainer = (function (_Component) {
  function ReduxContainer(props, context) {
    _classCallCheck(this, ReduxContainer);

    _get(Object.getPrototypeOf(ReduxContainer.prototype), 'constructor', this).call(this, props, context);
    this.handleChange = this.handleChange.bind(this);
    this.update(props);
  }

  _inherits(ReduxContainer, _Component);

  _createClass(ReduxContainer, [{
    key: 'componentWillReceiveProps',
    value: function componentWillReceiveProps(nextProps) {
      this.update(nextProps);
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      this.unsubscribe();
    }
  }, {
    key: 'update',
    value: function update(props) {
      var stores = props.stores;
      var actions = props.actions;

      (0, _invariant2['default'])((0, _lodashLangIsPlainObject2['default'])(actions) && _Object$keys(actions).every(function (key) {
        return typeof actions[key] === 'function';
      }), '"actions" must be a plain object with functions as values. Did you misspell an import?');
      (0, _invariant2['default'])(Array.isArray(stores) && stores.every(function (s) {
        return typeof s === 'function';
      }), '"stores" must be an array of functions. Did you misspell an import?');

      var _context$redux = this.context.redux;
      var wrapActionCreator = _context$redux.wrapActionCreator;
      var observeStores = _context$redux.observeStores;
      var getStoreKey = _context$redux.getStoreKey;

      this.actions = (0, _lodashObjectMapValues2['default'])(props.actions, wrapActionCreator);

      if (this.unsubscribe) {
        this.unsubscribe();
      }

      this.mapState = stores.length === 1 ? function (state) {
        return state[getStoreKey(stores[0])];
      } : _lodashUtilityIdentity2['default'];

      this.unsubscribe = observeStores(stores, this.handleChange);
    }
  }, {
    key: 'handleChange',
    value: function handleChange(stateFromStores) {
      var nextState = this.mapState(stateFromStores);
      if (this.state) {
        this.setState(nextState);
      } else {
        this.state = nextState;
      }
    }
  }, {
    key: 'render',
    value: function render() {
      return this.props.children(_extends({}, this.actions, this.state));
    }
  }], [{
    key: 'contextTypes',
    value: {
      redux: _react.PropTypes.object.isRequired
    },
    enumerable: true
  }, {
    key: 'propTypes',
    value: {
      children: _react.PropTypes.func.isRequired,
      actions: _react.PropTypes.object.isRequired,
      stores: _react.PropTypes.arrayOf(_react.PropTypes.func.isRequired).isRequired
    },
    enumerable: true
  }, {
    key: 'defaultProps',
    value: {
      stores: [],
      actions: {}
    },
    enumerable: true
  }]);

  return ReduxContainer;
})(_react.Component);

exports['default'] = ReduxContainer;
module.exports = exports['default'];

==> redux-0.6.1.tgz: package/lib/Container.js <==
'use strict';

var _inherits = require('babel-runtime/helpers/inherits')['default'];

var _get = require('babel-runtime/helpers/get')['default'];

var _createClass = require('babel-runtime/helpers/create-class')['default'];

var _classCallCheck = require('babel-runtime/helpers/class-call-check')['default'];

var _Object$defineProperty = require('babel-runtime/core-js/object/define-property')['default'];

var _Object$keys = require('babel-runtime/core-js/object/keys')['default'];

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

_Object$defineProperty(exports, '__esModule', {
  value: true
});

var _react = require('react');

var _lodashObjectValues = require('lodash/object/values');

var _lodashObjectValues2 = _interopRequireDefault(_lodashObjectValues);

var _lodashObjectMapValues = require('lodash/object/mapValues');

var _lodashObjectMapValues2 = _interopRequireDefault(_lodashObjectMapValues);

var _invariant = require('invariant');

var _invariant2 = _interopRequireDefault(_invariant);

var _lodashLangIsPlainObject = require('lodash/lang/isPlainObject');

var _lodashLangIsPlainObject2 = _interopRequireDefault(_lodashLangIsPlainObject);

var _lodashLangIsFunction = require('lodash/lang/isFunction');

var _lodashLangIsFunction2 = _interopRequireDefault(_lodashLangIsFunction);

var ReduxContainer = (function (_Component) {
  function ReduxContainer(props, context) {
    _classCallCheck(this, ReduxContainer);

    _get(Object.getPrototypeOf(ReduxContainer.prototype), 'constructor', this).call(this, props, context);
    this.handleChange = this.handleChange.bind(this);
    this.update(props);
  }

  _inherits(ReduxContainer, _Component);

  _createClass(ReduxContainer, [{
    key: 'componentWillReceiveProps',
    value: function componentWillReceiveProps(nextProps) {
      this.update(nextProps);
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      this.unsubscribe();
    }
  }, {
    key: 'update',
    value: function update(props) {
      var stores = props.stores;
      var actions = props.actions;

      if (process.env.NODE_ENV !== 'production') {
        (0, _invariant2['default'])((0, _lodashLangIsPlainObject2['default'])(actions), '"actions" must be a plain object with functions as values. Instead received: %s.', actions);
        (0, _invariant2['default'])((0, _lodashLangIsPlainObject2['default'])(stores), '"stores" must be a plain object with functions as values. Instead received: %s.', stores);
        _Object$keys(actions).forEach(function (key) {
          return (0, _invariant2['default'])((0, _lodashLangIsFunction2['default'])(actions[key]), 'Expected "%s" in "actions" to be a function. Instead received: %s.', key, actions[key]);
        });
        _Object$keys(stores).forEach(function (key) {
          return (0, _invariant2['default'])((0, _lodashLangIsFunction2['default'])(stores[key]), 'Expected "%s" in "stores" to be a function. Instead received: %s.', key, stores[key]);
        });
      }

      var _context$redux = this.context.redux;
      var wrapActionCreator = _context$redux.wrapActionCreator;
      var observeStores = _context$redux.observeStores;

      this.actions = (0, _lodashObjectMapValues2['default'])(props.actions, wrapActionCreator);

      if (this.unsubscribe) {
        this.unsubscribe();
      }

      this.unsubscribe = observeStores((0, _lodashObjectValues2['default'])(stores), this.handleChange);
    }
  }, {
    key: 'mapState',
    value: function mapState(stateFromStores) {
      var getStoreKey = this.context.redux.getStoreKey;

      return (0, _lodashObjectMapValues2['default'])(this.props.stores, function (store) {
        return stateFromStores[getStoreKey(store)];
      });
    }
  }, {
    key: 'handleChange',
    value: function handleChange(stateFromStores) {
      var nextState = this.mapState(stateFromStores);
      if (this.state) {
        this.setState(nextState);
      } else {
        this.state = nextState;
      }
    }
  }, {
    key: 'render',
    value: function render() {
      return this.props.children({
        state: this.state,
        actions: this.actions
      });
    }
  }], [{
    key: 'contextTypes',
    value: {
      redux: _react.PropTypes.object.isRequired
    },
    enumerable: true
  }, {
    key: 'propTypes',
    value: {
      children: _react.PropTypes.func.isRequired,
      actions: _react.PropTypes.objectOf(_react.PropTypes.func.isRequired).isRequired,
      stores: _react.PropTypes.objectOf(_react.PropTypes.func.isRequired).isRequired
    },
    enumerable: true
  }, {
    key: 'defaultProps',
    value: {
      stores: {},
      actions: {}
    },
    enumerable: true
  }]);

  return ReduxContainer;
})(_react.Component);

exports['default'] = ReduxContainer;
module.exports = exports['default'];
